using System;
using System.ComponentModel;
using System.Drawing;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using TSSuperTrend.Utility;

namespace NinjaTrader.Strategy
{
    [Description("TSSuperTrend  Strategy Sample")]
    public class TSSuperTrendStrategySample : Strategy
    {
        //SuperTrend Settings
        private Indicator.TSSuperTrend st           = null;
        private int                    length       = 14;
        private double                 multiplier   = 2.618;
        private bool                   showArrows   = false;
        private bool                   colorBars    = false;
        private MovingAverageType      maType       = MovingAverageType.HMA;
        private SuperTrendMode         smode        = SuperTrendMode.ATR;
        private int                    smooth       = 14;
        private Color                  barColorUp   = Color.Blue;
        private Color                  barColorDown = Color.Red;
        private bool                   playAlert    = false;
        private string                 longAlert    = "Alert4.wav";
        private string                 shortAlert   = "Alert4.wav";

        protected override void Initialize()
        {
            st              = TSSuperTrend(length, maType, multiplier, smooth, smode);
            st.ShowArrows   = showArrows;
            st.ColorBars    = colorBars;
            st.BarColorDown = barColorDown;
            st.BarColorUp   = barColorUp;
            st.PlayAlert    = playAlert;
            st.LongAlert    = longAlert;
            st.ShortAlert   = shortAlert;
            Add(st);
        }

        protected override void OnBarUpdate()
        {
            if (st.Trend[0] && !st.Trend[1])
                EnterLong();
            else
                if (st.Trend[1] && !st.Trend[0])
                    EnterShort();
        }

        #region Properties
        [Description("SuperTrendMode")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST1. SuperTrend Mode")]
        public SuperTrendMode StMode
        {
            get { return smode; }
            set { smode = value; }
        }

        [Description("ATR/DT Period")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST2. Period")]
        public int Length
        {
            get { return length; }
            set { length = Math.Max(1, value); }
        }

        [Description("ATR Multiplier")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST3. Multiplier")]
        public double Multiplier
        {
            get { return multiplier; }
            set { multiplier = Math.Max(0.0001, value); }
        }

        [Description("Moving Average Type for smoothing")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST4. Moving Average Type")]
        public MovingAverageType MaType
        {
            get { return maType; }
            set { maType = value; }
        }

        [Description("Smoothing Period")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST5. SmoothingPeriod (MA)")]
        public int Smooth
        {
            get { return smooth; }
            set { smooth = Math.Max(1, value); }
        }

        [Description("Show Arrows when Trendline is violated?")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST6. Show Arrows?")]
        public bool ShowArrows
        {
            get { return showArrows; }
            set { showArrows = value; }
        }

        [Description("Color the bars in the direction of the trend?")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST7. Color Bars?")]
        public bool ColorBars
        {
            get { return colorBars; }
            set { colorBars = value; }
        }

        [XmlIgnore]
        [Description("Color of up bars.")]
        [Category("Parameters")]
        [Gui.Design.DisplayNameAttribute("ST8. Up color")]
        public Color BarColorUp
        {
            get { return barColorUp; }
            set { barColorUp = value; }
        }

        [Browsable(false)]
        public string BarColorUpSerialize
        {
            get { return Gui.Design.SerializableColor.ToString(barColorUp); }
            set { barColorUp = Gui.Design.SerializableColor.FromString(value); }
        }

        [XmlIgnore]
        [Description("Color of down bars.")]
        [Category("Parameters")]
        [Gui.Design.DisplayNameAttribute("ST9. Down color")]
        public Color BarColorDown
        {
            get { return barColorDown; }
            set { barColorDown = value; }
        }

        [Browsable(false)]
        public string BarColorDownSerialize
        {
            get { return Gui.Design.SerializableColor.ToString(barColorDown); }
            set { barColorDown = Gui.Design.SerializableColor.FromString(value); }
        }

        [Description("Play Alert")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST91. Play Alert?")]
        public bool PlayAlert
        {
            get { return playAlert; }
            set { playAlert = value; }
        }

        [Description("File Name for long alert")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST92. Long Alert")]
        public string LongAlert
        {
            get { return longAlert; }
            set { longAlert = value; }
        }

        [Description("File Name for short alert")]
        [Category("Parameters")]
        [Gui.Design.DisplayName("ST93. Short Alert")]
        public string ShortAlert
        {
            get { return shortAlert; }
            set { shortAlert = value; }
        }

        #endregion
    }
}
